# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Email'
        db.create_table(u'db_email_backend_email', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('create_date', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('subject', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('body', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('content_subtype', self.gf('django.db.models.fields.CharField')(max_length=254)),
            ('from_email', self.gf('django.db.models.fields.CharField')(max_length=254, blank=True)),
            ('to', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('cc', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('bcc', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('headers', self.gf('django.db.models.fields.TextField')(blank=True)),
        ))
        db.send_create_signal(u'db_email_backend', ['Email'])

        # Adding model 'EmailAlternative'
        db.create_table(u'db_email_backend_emailalternative', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('email', self.gf('django.db.models.fields.related.ForeignKey')(related_name=u'alternatives', to=orm['db_email_backend.Email'])),
            ('content', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('mimetype', self.gf('django.db.models.fields.CharField')(max_length=254, blank=True)),
        ))
        db.send_create_signal(u'db_email_backend', ['EmailAlternative'])

        # Adding model 'EmailAttachment'
        db.create_table(u'db_email_backend_emailattachment', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('email', self.gf('django.db.models.fields.related.ForeignKey')(related_name=u'attachments', to=orm['db_email_backend.Email'])),
            ('filename', self.gf('django.db.models.fields.CharField')(max_length=1000, blank=True)),
            ('mimetype', self.gf('django.db.models.fields.CharField')(max_length=254, blank=True)),
            ('file', self.gf('django.db.models.fields.files.FileField')(max_length=100)),
        ))
        db.send_create_signal(u'db_email_backend', ['EmailAttachment'])


    def backwards(self, orm):
        # Deleting model 'Email'
        db.delete_table(u'db_email_backend_email')

        # Deleting model 'EmailAlternative'
        db.delete_table(u'db_email_backend_emailalternative')

        # Deleting model 'EmailAttachment'
        db.delete_table(u'db_email_backend_emailattachment')


    models = {
        u'db_email_backend.email': {
            'Meta': {'object_name': 'Email'},
            'bcc': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'body': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'cc': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'content_subtype': ('django.db.models.fields.CharField', [], {'max_length': '254'}),
            'create_date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'from_email': ('django.db.models.fields.CharField', [], {'max_length': '254', 'blank': 'True'}),
            'headers': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'subject': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'to': ('django.db.models.fields.TextField', [], {'blank': 'True'})
        },
        u'db_email_backend.emailalternative': {
            'Meta': {'object_name': 'EmailAlternative'},
            'content': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'email': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "u'alternatives'", 'to': u"orm['db_email_backend.Email']"}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'mimetype': ('django.db.models.fields.CharField', [], {'max_length': '254', 'blank': 'True'})
        },
        u'db_email_backend.emailattachment': {
            'Meta': {'object_name': 'EmailAttachment'},
            'email': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "u'attachments'", 'to': u"orm['db_email_backend.Email']"}),
            'file': ('django.db.models.fields.files.FileField', [], {'max_length': '100'}),
            'filename': ('django.db.models.fields.CharField', [], {'max_length': '1000', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'mimetype': ('django.db.models.fields.CharField', [], {'max_length': '254', 'blank': 'True'})
        }
    }

    complete_apps = ['db_email_backend']


# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.core.files.base import ContentFile
from django.core.mail.backends.base import BaseEmailBackend

from .models import Email, EmailAlternative, EmailAttachment

class DBEmailBackend(BaseEmailBackend):
    def send_messages(self, email_messages):
        for msg in email_messages:
            try:
                email = Email.objects.create(
                    subject=msg.subject,
                    body=msg.body,
                    content_subtype=msg.content_subtype,
                    from_email=msg.from_email,
                    to='; '.join(msg.to),
                    cc='; '.join(msg.cc),
                    bcc='; '.join(msg.bcc),
                    headers='\n'.join('{}: {}'.format(k, v)
                                      for k, v in msg.extra_headers.items()),
                )
                alternatives = getattr(msg, 'alternatives', [])
                for content, mimetype in alternatives:
                    EmailAlternative.objects.create(
                        email=email,
                        content=content,
                        mimetype=mimetype or '',
                    )

                for filename, content, mimetype in msg.attachments:
                    attachment = EmailAttachment.objects.create(
                        email=email,
                        filename=filename,
                        mimetype=mimetype or '',
                    )
                    attachment.file.save(filename, ContentFile(content))
            except:
                if not self.fail_silently:
                    raise

        return len(email_messages)



#!/usr/bin/env python

import os
import sys

from distutils.core import setup

import db_email_backend

if sys.argv[-1] == 'publish':
    os.system("python setup.py sdist upload")
    sys.exit()

long_description = open('README.md').read()

setup_args = dict(
    name='django-db-email-backend',
    version=db_email_backend.__version__,
    description='Django email backend for storing messages to a database.',
    long_description=long_description,
    author='Jeremy Satterfield',
    author_email='jsatt@jsatt.com',
    url='https://github.com/jsatt/django-db-email-backend',
    license="MIT License",
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Topic :: Software Development',
    ],
    packages=[
        'db_email_backend',
        'db_email_backend.migrations',
        'db_email_backend.south_migrations'
    ],
    install_requires=[
        "django>=1.4",
        "pytz",
    ],
)

if __name__ == '__main__':
    setup(**setup_args)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.contrib import admin

from .models import Email, EmailAlternative, EmailAttachment


class EmailAlternativeInline(admin.StackedInline):
    model = EmailAlternative
    readonly_fields = ('mimetype', 'content')
    extra = 0
    max_num = 0
    can_delete = False


class EmailAttachmentInline(admin.StackedInline):
    model = EmailAttachment
    readonly_fields = ('filename', 'mimetype', 'file')
    extra = 0
    max_num = 0
    can_delete = False


class EmailAdmin(admin.ModelAdmin):
    fields = (
        ('from_email', 'create_date', 'content_subtype'),
        ('to', 'cc', 'bcc'),
        'subject', 'body', 'headers')
    readonly_fields = (
        'create_date','from_email', 'to', 'cc', 'bcc', 'subject', 'body', 'content_subtype', 'headers')
    list_display = ('subject', 'to', 'from_email', 'create_date', 'attachment_count', 'alternative_count')
    list_filter = ('content_subtype',)
    date_hierarchy = 'create_date'
    search_fields = ('to', 'from_email', 'cc', 'bcc', 'subject', 'body')
    inlines = (EmailAlternativeInline, EmailAttachmentInline)

    def attachment_count(self, instance):
        return instance.attachments.count()
    attachment_count.short_description = 'Attachments'

    def alternative_count(self, instance):
        return instance.alternatives.count()
    alternative_count.short_description = 'Alternatives'

    def has_add_permission(self, request, obj=None):
        return False

admin.site.register(Email, EmailAdmin)


